@@ -39,10 +39,10 @@ int main(int argc, char *argv[])
     QApplication app(argc, argv);
     app.setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
     QCommandLineParser parser;
-    parser.setApplicationDescription("PlotView3DTest");
-    parser.addOption(QCommandLineOption("all-disabled", app.tr("marks all the plots as not visible")));
-    parser.addOption(QCommandLineOption("simple-rotation", app.tr("doesn't let you rotate the Z axis")));
-    parser.addOption(QCommandLineOption("experimental-view", app.tr("runs the view under development")));
+    parser.setApplicationDescription(QStringLiteral("PlotView3DTest"));
+    parser.addOption(QCommandLineOption(QStringLiteral("all-disabled"), app.tr("marks all the plots as not visible")));
+    parser.addOption(QCommandLineOption(QStringLiteral("simple-rotation"), app.tr("doesn't let you rotate the Z axis")));
+    parser.addOption(QCommandLineOption(QStringLiteral("experimental-view"), app.tr("runs the view under development")));
     parser.addHelpOption();
     parser.process(app);
 
@@ -60,33 +60,33 @@ int main(int argc, char *argv[])
 
     //BEGIN test calls
     PlotsFactory* s = PlotsFactory::self();
-    model->addPlot(s->requestPlot(Analitza::Expression("t->vector{cos(t), sin(t), t}"), Dim3D).create(Qt::green, "curve"));
-    model->addPlot(s->requestPlot(Analitza::Expression("t->vector {t,t**2,t}"), Dim3D).create(Qt::green, "parametric"));
-    model->addPlot(s->requestPlot(Analitza::Expression("(t,p)->2"), Dim3D).create(Qt::darkGreen, "sphere-sphcoords"));
-    model->addPlot(s->requestPlot(Analitza::Expression("(r,p)->p"), Dim3D).create(Qt::magenta, "cyl"));
-    model->addPlot(s->requestPlot(Analitza::Expression("piecewise{(x^2 + y^2 +z^2 < 35)?2 - (cos(x + (1+power(5,0.5))/2*y) + cos(x - (1+power(5,0.5))/2*y) + cos(y + (1+power(5,0.5))/2*z) + cos(y - (1+power(5,0.5))/2*z) + cos(z - (1+power(5,0.5))/2*x) + cos(z + (1+power(5,0.5))/2*x)),?1}=0"), Dim3D).create(QColor(40, 87, 159), "complex"));
-    model->addPlot(s->requestPlot(Analitza::Expression("(x^2 + y^2 - 1) * ( x^2 + z^2 - 1) = 1"), Dim3D).create(Qt::cyan, "implicit 0"));
-    model->addPlot(s->requestPlot(Analitza::Expression("(x,y)->(x*x-y*y)/8"), Dim3D).create(Qt::yellow, "z-map"));
-    model->addPlot(s->requestPlot(Analitza::Expression("x*x+y*y-z*z= 1/2"), Dim3D).create(Qt::darkBlue, "implicit 2"));
+    model->addPlot(s->requestPlot(Analitza::Expression(QStringLiteral("t->vector{cos(t), sin(t), t}")), Dim3D).create(Qt::green, QStringLiteral("curve")));
+    model->addPlot(s->requestPlot(Analitza::Expression(QStringLiteral("t->vector {t,t**2,t}")), Dim3D).create(Qt::green, QStringLiteral("parametric")));
+    model->addPlot(s->requestPlot(Analitza::Expression(QStringLiteral("(t,p)->2")), Dim3D).create(Qt::darkGreen, QStringLiteral("sphere-sphcoords")));
+    model->addPlot(s->requestPlot(Analitza::Expression(QStringLiteral("(r,p)->p")), Dim3D).create(Qt::magenta, QStringLiteral("cyl")));
+    model->addPlot(s->requestPlot(Analitza::Expression(QStringLiteral("piecewise{(x^2 + y^2 +z^2 < 35)?2 - (cos(x + (1+power(5,0.5))/2*y) + cos(x - (1+power(5,0.5))/2*y) + cos(y + (1+power(5,0.5))/2*z) + cos(y - (1+power(5,0.5))/2*z) + cos(z - (1+power(5,0.5))/2*x) + cos(z + (1+power(5,0.5))/2*x)),?1}=0")), Dim3D).create(QColor(40, 87, 159), QStringLiteral("complex")));
+    model->addPlot(s->requestPlot(Analitza::Expression(QStringLiteral("(x^2 + y^2 - 1) * ( x^2 + z^2 - 1) = 1")), Dim3D).create(Qt::cyan, QStringLiteral("implicit 0")));
+    model->addPlot(s->requestPlot(Analitza::Expression(QStringLiteral("(x,y)->(x*x-y*y)/8")), Dim3D).create(Qt::yellow, QStringLiteral("z-map")));
+    model->addPlot(s->requestPlot(Analitza::Expression(QStringLiteral("x*x+y*y-z*z= 1/2")), Dim3D).create(Qt::darkBlue, QStringLiteral("implicit 2")));
     //END test calls
 
-    if(parser.isSet("all-disabled"))
+    if(parser.isSet(QStringLiteral("all-disabled")))
         for(int i=0; i<model->rowCount(); i++)
             model->setData(model->index(i), false, Qt::CheckStateRole);
 
 
     central->addWidget(viewsource);
-    if (parser.isSet("experimental-view")) {
+    if (parser.isSet(QStringLiteral("experimental-view"))) {
         PlotsView3DES *view3des = new PlotsView3DES(central);
         view3des->setSelectionModel(viewsource->selectionModel());
-        view3des->setUseSimpleRotation(parser.isSet("simple-rotation"));
+        view3des->setUseSimpleRotation(parser.isSet(QStringLiteral("simple-rotation")));
         view3des->setModel(model);
         central->addWidget(view3des);
         view3des->setFocus();
     } else {
         PlotsView3D *view3d = new PlotsView3D(central);
         view3d->setSelectionModel(viewsource->selectionModel());
-        view3d->setUseSimpleRotation(parser.isSet("simple-rotation"));
+        view3d->setUseSimpleRotation(parser.isSet(QStringLiteral("simple-rotation")));
         view3d->setModel(model);
         central->addWidget(view3d);
         view3d->setFocus();
